.. _modules_base:

Module interface
================

The base/parent module interface that the
actual module implementations inherit from.

Performs the actual notification registration
and handling of callbacks, but leaves everything else
to the actual module implementations.

API
---

.. automodule:: pymetawear.modules.base
   :members:
